<template>
    <div class="system-user-container">
        <el-card shadow="hover">
            <div class="system-user-search mb15">
              <el-select v-model="listQuery.searchParams.workType" clearable size="default">
                <el-option
                    v-for="item in workTypeList"
                    :key="item.value"
                    :label="item.label"
                    :value="item.value"
                />
              </el-select>
                <el-button size="default" type="primary" class="ml10" @click="initSaftyTableData">
                    <el-icon>
                        <ele-Search />
                    </el-icon>
                    查询
                </el-button>
                <el-button size="default" type="success" class="ml10" @click="onOpenSaftyDialog('新增', '')">
                    <el-icon>
                        <ele-FolderAdd />
                    </el-icon>
                    新增
                </el-button>
            </div>
            <el-table :data="saftyTableData.data" style="width: 100%">
                <el-table-column prop="orderNum" label="编号" width="60" align="center"/>
                <el-table-column prop="workTypeDesc" label="作业类型" align="center" show-overflow-tooltip></el-table-column>
                <el-table-column prop="measureContent" label="安全措施内容" align="center" show-overflow-tooltip></el-table-column>
                <el-table-column prop="gmtCreateUname" label="创建人" align="center" show-overflow-tooltip></el-table-column>
                <el-table-column prop="gmtCreate" label="创建时间"  align="center" show-overflow-tooltip></el-table-column>
                <el-table-column prop="gmtModifiedUname" label="最后修改人" align="center" show-overflow-tooltip></el-table-column>
                <el-table-column prop="gmtModified" label="最后修改时间" align="center" show-overflow-tooltip></el-table-column>
                <el-table-column label="操作" width="100" align="center">
                    <template #default="scope">
                        <el-button size="small" text type="primary" @click="onOpenSaftyDialog('查看', scope.row)">查看</el-button>
                        <el-button size="small" text type="primary" @click="onOpenSaftyDialog('修改', scope.row)">修改</el-button>
                        <el-button style="color: red" size="small" text type="primary" @click="onRowDel(scope.row)">删除</el-button>
                    </template>
                </el-table-column>
            </el-table>
            <br />
            <el-pagination @size-change="onHandleSizeChange" @current-change="onHandleCurrentChange" class="page-position" :pager-count="5" :page-sizes="[10, 20, 30]" v-model:current-page="listQuery.pageIndex" background v-model:page-size="listQuery.pageSize" layout="total, sizes, prev, pager, next, jumper" :total="saftyTableData.total"> </el-pagination>
            <br />
            <br />
        </el-card>
        <safty-dialog ref="safeRef" @getSaftyList="initSaftyTableData"/>
    </div>
</template>

<script lang="ts">
import { toRefs, reactive, onMounted, ref, defineComponent } from 'vue';
import { ElMessageBox, ElMessage } from 'element-plus';
import saftyDialog from '/@/views/system/saftyManage/component/saftyDialog.vue';
import { saftyApi } from '/@/api/systemManage/saftyManage';
import { dutyApi } from '/@/api/systemManage/duty';
import { departmentApi } from '/@/api/systemManage/department';
import { useRoleApi } from '/@/api/systemManage/role';

// 定义接口来定义对象的类型
interface TableDataRow {
    name: string;
    userNickname: string;
    roleSign: string;
    department: string[];
    phone: string;
    email: string;
    sex: string;
    password: string;
    overdueTime: Date;
    status: boolean;
    describe: string;
    createTime: string;
}
interface DepartmentDataRow {}
interface TableDataState {
    saftyTableData: {
        data: Array<TableDataRow>;
        total: number;
        loading: boolean;
    };
    listQuery: {
      pageIndex: number;
      pageSize: number;
      searchParams: {}
    };
    departmentList: [];
    roleList: [];
    dutyList: [];
    props:{};
    workTypeList: Array<TypeList>
}
interface TypeList {
  label: string,
  value: number
}

export default defineComponent({
    name: 'saftyManage',
    components: { saftyDialog },
    setup() {
        const safeRef = ref();
        const state = reactive<TableDataState>({
            saftyTableData: {
                data: [],
                total: 0,
                loading: false,
            },
            listQuery: {
              pageIndex: 1,
              pageSize: 10,
              searchParams: {
                workType: null
              }
            },
            departmentList: [],
            roleList: [],
            dutyList: [],
            props: {
              label: 'depName',
              value: 'depId',
              checkStrictly: true,
              emitPath: false
            },
            workTypeList: [
              {
                label: "动火作业",
                value: 1
              },
              {
                label: "受限空间作业",
                value: 2
              },
              {
                label: "吊装作业",
                value: 3
              },
              {
                label: "动土作业",
                value: 4
              },
              {
                label: "断路作业",
                value: 5
              },
              {
                label: "高处作业",
                value: 6
              },
              {
                label: "临时用电作业",
                value: 7
              },
              {
                label: "盲板抽堵作业",
                value: 8
              }
            ]
        });
        // 初始化表格数据
        const initSaftyTableData = async () => {
            let res = await saftyApi().getSaftyList(state.listQuery);
            if (res.data.code === '200') {
                state.saftyTableData.data = res.data.data;
                state.saftyTableData.total = res.data.total;
            } else {
                ElMessage({
                    type: 'warning',
                    message: res.data.msg
                });
            }
        };

        // 回显职务信息
        const parseNumber = (value: number) => {
            return state.dutyList.find((i) => i.positionId === value)?.positionName;
        };
        const getDepartmentData = async () => {
            let res = await departmentApi().getDepartmentList();
            if (res.data.code === '200') {
                state.departmentList = res.data.data;
            } else {
                ElMessage({
                    type: 'warning',
                    message: res.data.msg
                });
            }
        };

        const getRoleData = async () => {
            let res = await useRoleApi().getRoleList();
            if (res.data.code === '200') {
                state.roleList = res.data.data;
            } else {
                ElMessage({
                    type: 'warning',
                    message: res.data.msg
                });
            }
        };

      const getDutyData = async () => {
        let res = await dutyApi().getAllList({positionName: '',positionCode: ''});
        if (res.data.code === '200') {
          state.dutyList = res.data.data;
        } else {
          ElMessage({
            type: 'warning',
            message: res.data.msg
          });
        }
      };

        // 打开新增修改用户弹窗
        const onOpenSaftyDialog = (type: string, value: any) => {
            safeRef.value.openDialog(type, value, state.departmentList, state.roleList, state.dutyList);
        };

        // 删除用户
        const onRowDel = (row: TableDataRow) => {
            ElMessageBox.confirm(`此操作将永久删除该项安全措施，是否继续?`, '提示', {
                confirmButtonText: '确认',
                cancelButtonText: '取消',
                type: 'warning'
            })
                .then(async () => {
                    let res = await saftyApi().delSafty({id: row.id});
                    if (res.data.code === '200') {
                        ElMessage({
                            type: 'success',
                            duration: 2000,
                            message: '删除成功'
                        });
                        await initSaftyTableData();
                    } else {
                        ElMessage({
                            type: 'warning',
                            message: res.data.msg
                        });
                    }
                })
                .catch(() => {});
        };
        // 分页改变
        const onHandleSizeChange = (val: number) => {
            state.listQuery.pageSize = val;
            initSaftyTableData();
        };
        // 分页改变
        const onHandleCurrentChange = (val: number) => {
            state.listQuery.pageIndex = val;
            initSaftyTableData();
        };
        // 页面加载时
        onMounted(() => {
            let a = { name: 1, c: { name: 1 } };
            let b = Object.assign({}, a);
            b.c.name = 2;
            initSaftyTableData();
            getDepartmentData();
            getRoleData();
            getDutyData()
        });
        return {
            safeRef,
            onOpenSaftyDialog,
            onRowDel,
            parseNumber,
            onHandleSizeChange,
            initSaftyTableData,
            onHandleCurrentChange,
            ...toRefs(state)
        };
    }
});
</script>
<style  scoped>
:deep(.el-textarea.is-disabled .el-textarea__inner) {
    background-color: var(--el-card-bg-color);
    color: var(--el-input-text-color, var(--el-text-color-regular));
}
:deep(.el-input.is-disabled .el-input__inner) {
    color: var(--el-input-text-color, var(--el-text-color-regular));
}
:deep(.el-input.is-disabled .el-input__wrapper) {
    background-color: var(--el-card-bg-color);
}
</style>
